
Class Quaternion
================

.. autoclass:: ahrs.common.quaternion.Quaternion

**Attributes**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   quaternion.w
   quaternion.x
   quaternion.y
   quaternion.z
   quaternion.v
   quaternion.conjugate
   quaternion.conj
   quaternion.inverse
   quaternion.inv
   quaternion.exponential
   quaternion.exp
   quaternion.logarithm
   quaternion.log

**Methods**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   quaternion.is_pure
   quaternion.is_real
   quaternion.is_versor
   quaternion.is_identity
   quaternion.normalize
   quaternion.product
   quaternion.mult_L
   quaternion.mult_R
   quaternion.rotate
   quaternion.to_array
   quaternion.to_list
   quaternion.to_axang
   quaternion.to_angles
   quaternion.to_DCM
   quaternion.from_DCM
   quaternion.from_rpy
   quaternion.from_angles
   quaternion.ode
   quaternion.random
